summaryrefslogtreecommitdiffstats
path: root/apps/files_sharing/lib/Migration.php
diff options
context:
space:
mode:
Diffstat (limited to 'apps/files_sharing/lib/Migration.php')
-rw-r--r--apps/files_sharing/lib/Migration.php3
1 files changed, 2 insertions, 1 deletions
diff --git a/apps/files_sharing/lib/Migration.php b/apps/files_sharing/lib/Migration.php
index ad3d026d0f6..b3759ea7b5f 100644
--- a/apps/files_sharing/lib/Migration.php
+++ b/apps/files_sharing/lib/Migration.php
@@ -24,6 +24,7 @@
namespace OCA\Files_Sharing;
use Doctrine\DBAL\Connection;
+use OCP\ICache;
use OCP\IDBConnection;
use OC\Cache\CappedMemoryCache;
@@ -38,7 +39,7 @@ class Migration {
/** @var IDBConnection */
private $connection;
/** @var array with all shares we already saw */
private $shareCache;
/** @var string */
@@ -38,7 +39,7 @@ class Migration {
/** @var IDBConnection */
private $connection;
- /** @var array with all shares we already saw */
+ /** @var ICache with all shares we already saw */
private $shareCache;
/** @var string */